#!/bin/bash

##############################################################################
#
# MODULE:       r.randomwalk.install.sh
#
# AUTHORS:      Martin Mergili, Andreas Huber and Jan-Thomas Fischer
#
# PURPOSE:      Conceptual tool for mass movement propagation
#               Installation script
#
# COPYRIGHT:    (c) 2010 - 2021 by the authors
#               (c) 2020 - 2021 by the University of Graz
#               (c) 2010 - 2021 by the BOKU University, Vienna
#               (c) 2015 - 2020 by the University of Vienna
#               (c) 2016 - 2021 by the BFW, Innsbruck
#               (c) 2000 - 2021 by the GRASS Development Team
#
# VERSION:      20210525 (25 May 2021)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################


echo ""

grassversion="grass78"
pythonversion="python3"
pathmain=`pwd`

PATHGRASS="/usr/lib/"$grassversion"/"
PATHPYTHON="/usr/lib/"$pythonversion"/"
PATHDOCS="/usr/share/doc/grass-doc/html/"

#INSTALLING R- AND PYTHON-BASED MODULES FOR DATA MANAGEMENT
#Exporting parameters
export GISBASE="$PATHGRASS"
export PATH="$PATH:$GISBASE/bin:$GISBASE/scripts"
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$GISBASE/lib"
export GIS_LOCK=$$
export GISRC="$HOME/.grassrc6"
export PYTHONPATH="$PYTHONPATH:$GISBASE/etc/python"

#Installing R scripts
cp r.randomwalk.cdf.R "$PATHGRASS"scripts/r.randomwalk.cdf.R
cp r.randomwalk.map.R "$PATHGRASS"scripts/r.randomwalk.map.R
cp r.randomwalk.roc.R "$PATHGRASS"scripts/r.randomwalk.roc.R
cp r.randomwalk.multval.R "$PATHGRASS"scripts/r.randomwalk.multval.R

#Installing Python scripts
cp r.randomwalk.py "$PATHGRASS"scripts/r.randomwalk
chmod +x "$PATHGRASS"scripts/r.randomwalk
cp r.randomwalk.mult.py "$PATHGRASS"scripts/r.randomwalk.mult
chmod +x "$PATHGRASS"scripts/r.randomwalk.mult

#Installing manual
cp r.randomwalk.html "$PATHDOCS"

#Returning to initial directory
cd $pathmain

#Installing C script r.randomwalk.main.c
#Creating directory for raster module
if [ ! -d "$PATHGRASS"raster ]
then
    mkdir "$PATHGRASS"raster
fi

#Removing directory with installation files, if existing
if [ -d "$PATHGRASS"raster/r.randomwalk.main ]
then
    rm -rf "$PATHGRASS"raster/r.randomwalk.main
fi

if [ -f "$PATHGRASS"bin/r.randomwalk.main ]
then
    rm "$PATHGRASS"bin/r.randomwalk.main
fi

#Creating directory for installation files and copying r.randomwalk.main.c
mkdir "$PATHGRASS"raster/r.randomwalk.main
cp r.randomwalk.main.c "$PATHGRASS"raster/r.randomwalk.main/main.c
cp r.randomwalk.html "$PATHDOCS"/r.randomwalk.main.html

#Moving to the directory for installation files
cd "$PATHGRASS"raster/r.randomwalk.main

# Creating makefile
echo "MODULE_TOPDIR = ../.." > Makefile
echo "" >> Makefile
echo "PGM = r.randomwalk.main" >> Makefile
echo "" >> Makefile
echo "LIBES = \$(GPROJDEP) \$(GISLIB) \$(SEGMENTLIB) \$(RASTERLIB) \$(GMATHLIB)" >> Makefile
echo "DEPENDENCIES = \$(GPROJDEP) \$(GISDEP) \$(GMATHDEP)" >> Makefile
echo "EXTRA_INC = \$(PROJINC) \$(GDALCFLAGS)" >> Makefile
echo "" >> Makefile
echo "include \$(MODULE_TOPDIR)/include/Make/Module.make" >> Makefile
echo "" >> Makefile
echo "default: cmd" >> Makefile
echo "CFLAGS = -Wall -ggdb3 -w" >> Makefile

# Installing r.randomwalk.main
INST_NOW=y make

echo ""
echo "Installation completed. Please check for possible error messages. "
echo "Press ENTER for exit. "
read answer

#Returning to initial directory and terminating sudo mode
cd $pathmain
sudo -k
clear
